"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.objectFind = exports.mapFind = exports.arrayFind = exports.find = void 0;
function find(data, fn) {
    if (isArray(data))
        return arrayFind(data, fn);
    if (isMap(data))
        return mapFind(data, fn);
    if (isObject(data))
        return objectFind(data, fn);
    return null;
}
exports.find = find;
function arrayFind(data, fn) {
    const value = data.find(fn);
    return value === undefined ? null : value;
}
exports.arrayFind = arrayFind;
function mapFind(data, fn) {
    let index = 0;
    for (const item of data) {
        index += 1;
        if (fn(item, index, data)) {
            return item;
        }
    }
    return null;
}
exports.mapFind = mapFind;
function objectFind(data, fn) {
    let index = 0;
    for (const item of Object.entries(data)) {
        index += 1;
        if (fn(item, index, data)) {
            return item;
        }
    }
    return null;
}
exports.objectFind = objectFind;
// is.type
function isArray(value) {
    return Array.isArray(value);
}
function isMap(value) {
    return Object.prototype.toString.call(value) === '[object Map]';
}
function isObject(value) {
    return (value !== null &&
        (typeof value === 'object' || typeof value === 'function'));
}
